@@ -21,9 +21,8 @@ os.environ.setdefault("DJANGO_SETTINGS_MODULE", "conf.settings")
 # file. This includes Django's development server, if the WSGI_APPLICATION
 # setting points here.
 from django.core.wsgi import get_wsgi_application
-from tendenci.dj_static import Cling, MediaCling, ThemeCling
 
-application = Cling(MediaCling(ThemeCling(get_wsgi_application())))
+application = get_wsgi_application()
 
 # Apply WSGI middleware here.
 # from helloworld.wsgi import HelloWorldApplication
